@@ -2,7 +2,7 @@ package Proc::PersistentControl; # -*-perl-*-
 #
 # Author: Michael Staats 2014
 #
-# $Id: PersistentControl.pm 713 2015-03-13 12:05:17Z michael $
+# $Id: PersistentControl.pm 742 2015-08-07 13:30:38Z michael $
 #
 
 =head1 NAME
@@ -228,7 +228,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @ISA = qw(Exporter);
 
-$VERSION = '1.2';
+$VERSION = '1.4';
 
 use strict;
 use File::Path qw(mkpath rmtree); # legacy interface, works with older perls
@@ -526,7 +526,10 @@ sub _win_spawn {
     $Arg .= ' -d ' if ($_debugfh);
     my $timeout = $opt->{timeout} ? $opt->{timeout} : 0;
     $Arg .= " -t $timeout " if ($timeout > 0);
-    # well, if you have a '"' inside one of the arguments, I'm sorry...
+    # Try to escape "" in cmd.
+    # Will work in simple cases...
+    s/\"/\\\"/g foreach (@cmd);
+    # contruct final command
     $Arg .= "\"$pdir\" \"" . join('" "', @cmd) . '"';
 
     debug("perl \$Arg = '$Arg'");
@@ -610,7 +613,7 @@ sub _get_all_uids {
 
     opendir(D, $sdir) or croak "Cannot opendir '$sdir': $!\n";
     while (my $d = readdir(D)) {
-	if ($d =~ m/^PPC-/) {
+	if ($d =~ m/^PPC-/ and -f "$sdir/$d/info") {
 	    push(@ret, $d);
 	    debug("found job info dir \"$d\"");
 	}
@@ -812,10 +815,10 @@ sub ProcList {
     my @uidlist = _make_uid_list($self->{sdir});
     
     UID: foreach my $UID (@uidlist) {
-	if ($key) {
-	    my $i = _get_info_by_uid($self->{sdir}, $UID);
-	    next UID unless ($i->{$key} eq $val);
-	}
+	my $i = _get_info_by_uid($self->{sdir}, $UID);
+	next UID unless ($i);
+	next UID if ($key and $i->{$key} ne $val);
+	
 	my $Proc = {
 	    _PPCUID => $UID,
 	    _controller => $self
